@@ -15,18 +15,18 @@
  *
 */
 
-#include "ignition/gazebo/components/CanonicalLink.hh"
-#include "ignition/gazebo/components/Joint.hh"
-#include "ignition/gazebo/components/Link.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/ParentEntity.hh"
-#include "ignition/gazebo/components/PoseCmd.hh"
-#include "ignition/gazebo/components/SelfCollide.hh"
-#include "ignition/gazebo/components/SourceFilePath.hh"
-#include "ignition/gazebo/components/Static.hh"
-#include "ignition/gazebo/components/WindMode.hh"
-#include "ignition/gazebo/Model.hh"
+#include "gz/sim/components/CanonicalLink.hh"
+#include "gz/sim/components/Joint.hh"
+#include "gz/sim/components/Link.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/ParentEntity.hh"
+#include "gz/sim/components/PoseCmd.hh"
+#include "gz/sim/components/SelfCollide.hh"
+#include "gz/sim/components/SourceFilePath.hh"
+#include "gz/sim/components/Static.hh"
+#include "gz/sim/components/WindMode.hh"
+#include "gz/sim/Model.hh"
 
 class ignition::gazebo::ModelPrivate
 {
@@ -34,10 +34,10 @@ class ignition::gazebo::ModelPrivate
   public: Entity id{kNullEntity};
 };
 
-using namespace ignition::gazebo;
+using namespace gz::sim;
 
 //////////////////////////////////////////////////
-Model::Model(gazebo::Entity _entity)
+Model::Model(gz::sim::Entity _entity)
   : dataPtr(std::make_unique<ModelPrivate>())
 {
   this->dataPtr->id = _entity;
