@@ -14,21 +14,21 @@
  * limitations under the License.
  *
 */
-#include "ignition/gazebo/ServerConfig.hh"
+#include "gz/sim/ServerConfig.hh"
 
 #include <tinyxml2.h>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/fuel_tools/FuelClient.hh>
-#include <ignition/fuel_tools/Result.hh>
-#include <ignition/math/Rand.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/Util.hh>
+#include <gz/fuel_tools/FuelClient.hh>
+#include <gz/fuel_tools/Result.hh>
+#include <gz/math/Rand.hh>
 
-#include "ignition/gazebo/Util.hh"
+#include "gz/sim/Util.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 /// \brief Private data for PluginInfoConfig.
 class ignition::gazebo::ServerConfig::PluginInfoPrivate
@@ -270,7 +270,7 @@ class ignition::gazebo::ServerConfigPrivate
   public: std::string logRecordCompressPath = "";
 
   /// \brief Path to where simulation resources, such as models downloaded
-  /// from fuel.ignitionrobotics.org, should be stored.
+  /// from fuel.gazebosim.org, should be stored.
   public: std::string resourceCache = "";
 
   /// \brief File containing physics engine plugin. If empty, DART will be used.
@@ -562,7 +562,7 @@ ServerConfig::LogPlaybackPlugin() const
 {
   auto entityName = "*";
   auto entityType = "world";
-  auto pluginName = "ignition::gazebo::systems::LogPlayback";
+  auto pluginName = "gz::sim::systems::LogPlayback";
   auto pluginFilename = "ignition-gazebo-log-system";
 
   sdf::ElementPtr playbackElem;
@@ -592,7 +592,7 @@ ServerConfig::LogRecordPlugin() const
 {
   auto entityName = "*";
   auto entityType = "world";
-  auto pluginName = "ignition::gazebo::systems::LogRecord";
+  auto pluginName = "gz::sim::systems::LogRecord";
   auto pluginFilename = std::string("ignition-gazebo") +
     IGNITION_GAZEBO_MAJOR_VERSION_STR + "-log-system";
 
@@ -800,7 +800,7 @@ parsePluginsFromDoc(const tinyxml2::XMLDocument &_doc)
 
 /////////////////////////////////////////////////
 std::list<ServerConfig::PluginInfo>
-gazebo::parsePluginsFromFile(const std::string &_fname)
+ignition::gazebo::parsePluginsFromFile(const std::string &_fname)
 {
   tinyxml2::XMLDocument doc;
   doc.LoadFile(_fname.c_str());
@@ -809,7 +809,7 @@ gazebo::parsePluginsFromFile(const std::string &_fname)
 
 /////////////////////////////////////////////////
 std::list<ServerConfig::PluginInfo>
-gazebo::parsePluginsFromString(const std::string &_str)
+ignition::gazebo::parsePluginsFromString(const std::string &_str)
 {
   tinyxml2::XMLDocument doc;
   doc.Parse(_str.c_str());
@@ -819,7 +819,7 @@ gazebo::parsePluginsFromString(const std::string &_str)
 
 /////////////////////////////////////////////////
 std::list<ServerConfig::PluginInfo>
-gazebo::loadPluginInfo(bool _isPlayback)
+ignition::gazebo::loadPluginInfo(bool _isPlayback)
 {
   std::list<ServerConfig::PluginInfo> ret;
 
@@ -834,7 +834,7 @@ gazebo::loadPluginInfo(bool _isPlayback)
     if (common::exists(envConfig))
     {
       // Parse configuration stored in environment variable
-      ret = gazebo::parsePluginsFromFile(envConfig);
+      ret = gz::sim::parsePluginsFromFile(envConfig);
       if (ret.empty())
       {
         // This may be desired behavior, but warn just in case.
@@ -914,7 +914,7 @@ gazebo::loadPluginInfo(bool _isPlayback)
     }
   }
 
-  ret = gazebo::parsePluginsFromFile(defaultConfig);
+  ret = gz::sim::parsePluginsFromFile(defaultConfig);
 
   if (ret.empty())
   {
@@ -928,4 +928,3 @@ gazebo::loadPluginInfo(bool _isPlayback)
 
   return ret;
 }
-
