@@ -14,9 +14,9 @@
  * limitations under the License.
  *
 */
-#include "ignition/gazebo/System.hh"
+#include "gz/sim/System.hh"
 
-using namespace ignition::gazebo;
+using namespace gz::sim;
 
 //////////////////////////////////////////////////
 System::System() = default;
