@@ -17,28 +17,28 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/msgs/stringmsg.pb.h>
+#include <gz/msgs/stringmsg.pb.h>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/StringUtils.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/gui/Dialog.hh>
-#include <ignition/gui/MainWindow.hh>
-#include <ignition/transport/Node.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/StringUtils.hh>
+#include <gz/common/Util.hh>
+#include <gz/gui/Dialog.hh>
+#include <gz/gui/MainWindow.hh>
+#include <gz/transport/Node.hh>
+#include <gz/utilities/ExtraTestMacros.hh>
 
-#include "ignition/gazebo/gui/Gui.hh"
-#include "ignition/gazebo/test_config.hh"
+#include "gz/sim/gui/Gui.hh"
+#include "gz/sim/test_config.hh"
 #include "QuickStartHandler.hh"
 
 int gg_argc = 1;
 char **gg_argv = new char *[gg_argc];
 
-using namespace ignition;
+using namespace gz;
 using namespace ignition::gazebo::gui;
 
 /////////////////////////////////////////////////
-// https://github.com/ignitionrobotics/ign-gazebo/issues/8
+// https://github.com/gazebosim/gz-sim/issues/8
 TEST(GuiTest, IGN_UTILS_TEST_DISABLED_ON_MAC(PathManager))
 {
   common::Console::SetVerbosity(4);
