@@ -22,19 +22,19 @@
 #include <string>
 
 #include <ignition/msgs.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/gazebo/Events.hh"
-#include "ignition/gazebo/Conversions.hh"
-#include "ignition/common/Console.hh"
-#include "ignition/rendering/Marker.hh"
-#include "ignition/rendering/RenderingIface.hh"
-#include "ignition/rendering/Scene.hh"
+#include "gz/sim/Events.hh"
+#include "gz/sim/Conversions.hh"
+#include "gz/common/Console.hh"
+#include "gz/rendering/Marker.hh"
+#include "gz/rendering/RenderingIface.hh"
+#include "gz/rendering/Scene.hh"
 
-#include "ignition/gazebo/rendering/MarkerManager.hh"
+#include "gz/sim/rendering/MarkerManager.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 /// Private data for the MarkerManager class
 class ignition::gazebo::MarkerManagerPrivate
@@ -119,6 +119,9 @@ class ignition::gazebo::MarkerManagerPrivate
 
   /// \brief Topic name for the marker service
   public: std::string topicName = "/marker";
+
+  /// \brief Topic that publishes marker updates.
+  public: gz::transport::Node::Publisher markerPub;
 };
 
 /////////////////////////////////////////////////
@@ -189,6 +192,9 @@ bool MarkerManager::Init(const rendering::ScenePtr &_scene)
            << "_array service.\n";
   }
 
+  this->dataPtr->markerPub =
+    this->dataPtr->node.Advertise<msgs::Marker>(this->dataPtr->topicName);
+
   return true;
 }
 
@@ -215,6 +221,7 @@ void MarkerManagerPrivate::Update()
        markerIter != this->markerMsgs.end();)
   {
     this->ProcessMarkerMsg(*markerIter);
+    this->markerPub.Publish(*markerIter);
     this->markerMsgs.erase(markerIter++);
   }
 
