@@ -17,22 +17,22 @@
 
 #include "JointPositionController.hh"
 
-#include <ignition/msgs/double.pb.h>
+#include <gz/msgs/double.pb.h>
 
 #include <string>
 #include <unordered_set>
 
-#include <ignition/common/Profiler.hh>
-#include <ignition/math/PID.hh>
-#include <ignition/plugin/Register.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/math/PID.hh>
+#include <gz/plugin/Register.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/gazebo/components/JointForceCmd.hh"
-#include "ignition/gazebo/components/JointPosition.hh"
-#include "ignition/gazebo/Model.hh"
+#include "gz/sim/components/JointForceCmd.hh"
+#include "gz/sim/components/JointPosition.hh"
+#include "gz/sim/Model.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 using namespace systems;
 
 class ignition::gazebo::systems::JointPositionControllerPrivate
@@ -273,5 +273,9 @@ IGNITION_ADD_PLUGIN(JointPositionController,
                     JointPositionController::ISystemConfigure,
                     JointPositionController::ISystemPreUpdate)
 
+IGNITION_ADD_PLUGIN_ALIAS(JointPositionController,
+                          "gz::sim::systems::JointPositionController")
+
+// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(JointPositionController,
                           "ignition::gazebo::systems::JointPositionController")
