@@ -24,17 +24,17 @@
 #include <limits>
 #include <utility>
 
-#include <ignition/common/Profiler.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/plugin/Register.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/common/Util.hh>
+#include <gz/plugin/Register.hh>
 
 // bug https://github.com/protocolbuffers/protobuf/issues/5051
 #ifdef _WIN32
 #undef GetMessage
 #endif
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 using namespace systems;
 
 /// \brief Base class for input matchers.
@@ -652,14 +652,7 @@ bool TriggeredPublisher::MatchInput(const transport::ProtoMsg &_inputMsg)
   return std::all_of(this->matchers.begin(), this->matchers.end(),
                      [&](const auto &_matcher)
                      {
-                       try
-                       {
-                         return _matcher->Match(_inputMsg);
-                       } catch (const google::protobuf::FatalException &err)
-                       {
-                          ignerr << err.what() << std::endl;
-                          return false;
-                       }
+                       return _matcher->Match(_inputMsg);
                      });
 }
 
@@ -667,5 +660,9 @@ IGNITION_ADD_PLUGIN(TriggeredPublisher,
                     System,
                     TriggeredPublisher::ISystemConfigure)
 
+IGNITION_ADD_PLUGIN_ALIAS(TriggeredPublisher,
+                          "gz::sim::systems::TriggeredPublisher")
+
+// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(TriggeredPublisher,
                           "ignition::gazebo::systems::TriggeredPublisher")
