@@ -16,7 +16,7 @@
 */
 
 #include <gtest/gtest.h>
-#include <ignition/msgs/pose_v.pb.h>
+#include <gz/msgs/pose_v.pb.h>
 
 #include <algorithm>
 #include <climits>
@@ -26,40 +26,40 @@
 #include <numeric>
 #include <string>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/common/Filesystem.hh>
-#include <ignition/fuel_tools/Zip.hh>
-#include <ignition/transport/Node.hh>
-#include <ignition/transport/log/Batch.hh>
-#include <ignition/transport/log/Log.hh>
-#include <ignition/transport/log/MsgIter.hh>
-#include <ignition/transport/log/Playback.hh>
-#include <ignition/transport/log/QualifiedTime.hh>
-#include <ignition/math/Pose3.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Util.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/fuel_tools/Zip.hh>
+#include <gz/transport/Node.hh>
+#include <gz/transport/log/Batch.hh>
+#include <gz/transport/log/Log.hh>
+#include <gz/transport/log/MsgIter.hh>
+#include <gz/transport/log/Playback.hh>
+#include <gz/transport/log/QualifiedTime.hh>
+#include <gz/math/Pose3.hh>
 
 #include <sdf/Root.hh>
 #include <sdf/World.hh>
 #include <sdf/Element.hh>
 
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/LogPlaybackStatistics.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/ServerConfig.hh"
-#include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/test_config.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/LogPlaybackStatistics.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/Server.hh"
+#include "gz/sim/ServerConfig.hh"
+#include "gz/sim/SystemLoader.hh"
+#include "gz/sim/test_config.hh"
 
 #include "../helpers/Relay.hh"
 #include "../helpers/EnvTestFixture.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 static const std::string kBinPath(PROJECT_BINARY_PATH);
 
 // TODO(anyone) Support command line options for OSX, see
-// https://github.com/ignitionrobotics/ign-gazebo/issues/25
+// https://github.com/gazebosim/gz-sim/issues/25
 #ifndef __APPLE__
 static const std::string kSdfFileOpt =  // NOLINT(runtime/string)
 " ";
@@ -335,7 +335,7 @@ TEST_F(LogSystemTest, LogDefaults)
 
   // Test case 1:
   // No path specified on command line. This does not go through
-  // ign.cc, recording should take place in the `.ignition` directory
+  // gz.cc, recording should take place in the `.ignition` directory
   {
     // Change log path in SDF to empty
     sdf::Root recordSdfRoot;
@@ -371,7 +371,7 @@ TEST_F(LogSystemTest, LogDefaults)
   // Test case 2:
   // No path specified on command line (only --record, no --record-path).
   // No path specified in SDF.
-  // Run from command line, which should trigger ign.cc, which should initialize
+  // Run from command line, which should trigger gz.cc, which should initialize
   // ignLogDirectory() to default timestamp path. Both console and state logs
   // should be recorded here.
 
@@ -383,7 +383,7 @@ TEST_F(LogSystemTest, LogDefaults)
   entryList(logPath, entriesBefore);
 
   {
-    // Command line triggers ign.cc, which handles initializing ignLogDirectory
+    // Command line triggers gz.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + "--record " + kSdfFileOpt + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
@@ -436,7 +436,7 @@ TEST_F(LogSystemTest, LogPaths)
   // No path specified in C++ API.
   // LogIgnoreSdfPath is not set.
   // Should take SDF path. State log should be stored here. Console log is not
-  // initialized because ign.cc is not triggered.
+  // initialized because gz.cc is not triggered.
   {
     // Change log path in SDF to build directory
     sdf::Root recordSdfRoot;
@@ -486,7 +486,7 @@ TEST_F(LogSystemTest, LogPaths)
   // No path specified on command line (therefore LogIgnoreSdfPath is not set).
   // State log should be stored in SDF path.
   // Console log should be stored to default timestamp path ignLogDirectory
-  // because ign.cc is triggered by command line.
+  // because gz.cc is triggered by command line.
   {
     // Change log path in SDF to build directory
     sdf::Root recordSdfRoot;
@@ -501,7 +501,7 @@ TEST_F(LogSystemTest, LogPaths)
     ofs << recordSdfRoot.Element()->ToString("").c_str();
     ofs.close();
 
-    // Command line triggers ign.cc, which handles initializing ignLogDirectory
+    // Command line triggers gz.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + "--record " + kSdfFileOpt + tmpRecordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
@@ -544,7 +544,7 @@ TEST_F(LogSystemTest, LogPaths)
   // A different path is specified via C++ API.
   // LogIgnoreSdfPath is not set (pure C++ API usage).
   // Should store state.tlog to SDF path. Console log is not initialized
-  // because ign.cc is not triggered.
+  // because gz.cc is not triggered.
   std::string stateLogPath = this->logDir;
 
   std::string consoleLogPath = common::joinPaths(this->logsDir, "console");
@@ -590,7 +590,7 @@ TEST_F(LogSystemTest, LogPaths)
   // A different path is specified via C++ API.
   // LogIgnoreSdfPath is set (similar to specifying a path on command line).
   // Should take C++ API path. State log should be stored here. Console log is
-  // not initialized because ign.cc is not triggered.
+  // not initialized because gz.cc is not triggered.
   const std::string sdfPath = common::joinPaths(this->logsDir, "sdfPath");
   const std::string cppPath = common::joinPaths(this->logsDir, "cppPath");
   {
@@ -632,7 +632,7 @@ TEST_F(LogSystemTest, LogPaths)
   // A path is specified by --record-path on command line.
   // Both state and console logs should be stored here.
   {
-    // Command line triggers ign.cc, which handles initializing ignLogDirectory
+    // Command line triggers gz.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + "--record-path " + this->logDir + " " + kSdfFileOpt + recordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
@@ -674,7 +674,7 @@ TEST_F(LogSystemTest, LogPaths)
     ofs << recordSdfRoot.Element()->ToString("").c_str();
     ofs.close();
 
-    // Command line triggers ign.cc, which handles initializing ignLogDirectory
+    // Command line triggers gz.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + "--record-path " + cliPath + " " + kSdfFileOpt + tmpRecordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
@@ -1151,7 +1151,7 @@ TEST_F(LogSystemTest, LogOverwrite)
   // Path exists, no overwrite flag. LogRecord.cc should still overwrite by
   // default behavior whenever the specified path already exists.
   // Path is set by SDF.
-  // Server is run from command line, ign.cc should initialize new default
+  // Server is run from command line, gz.cc should initialize new default
   // timestamp directory, where console log should be recorded. State log should
   // be recorded to the path in SDF.
 
@@ -1185,7 +1185,7 @@ TEST_F(LogSystemTest, LogOverwrite)
     ofs << recordSdfRoot.Element()->ToString("").c_str();
     ofs.close();
 
-    // Command line triggers ign.cc, which handles initializing ignLogDirectory
+    // Command line triggers gz.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + kSdfFileOpt + tmpRecordSdfPath;
     std::cout << "Running command [" << cmd << "]" << std::endl;
@@ -1226,9 +1226,9 @@ TEST_F(LogSystemTest, LogOverwrite)
 
   // Test case 4:
   // Path exists, command line --log-overwrite, should overwrite by
-  // command-line logic in ign.cc
+  // command-line logic in gz.cc
   {
-    // Command line triggers ign.cc, which handles creating a unique path if
+    // Command line triggers gz.cc, which handles creating a unique path if
     // file already exists, so as to not overwrite
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 --log-overwrite "
       + "--record-path " + this->logDir + " " + kSdfFileOpt + recordSdfPath;
@@ -1254,9 +1254,9 @@ TEST_F(LogSystemTest, LogOverwrite)
 
   // Test case 5:
   // Path exists, no --log-overwrite, should create new files by command-line
-  // logic in ign.cc
+  // logic in gz.cc
   {
-    // Command line triggers ign.cc, which handles creating a unique path if
+    // Command line triggers gz.cc, which handles creating a unique path if
     // file already exists, so as to not overwrite
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + "--record-path " + this->logDir + " " + kSdfFileOpt + recordSdfPath;
@@ -1276,7 +1276,7 @@ TEST_F(LogSystemTest, LogOverwrite)
   // ign gazebo. server_main.cc is deprecated and does not have overwrite
   // renaming implemented. So will always overwrite. Will not test (#) type of
   // renaming on OS X until ign gazebo is fixed:
-  // https://github.com/ignitionrobotics/ign-gazebo/issues/25
+  // https://github.com/gazebosim/gz-sim/issues/25
 
   // New log files were created
   EXPECT_TRUE(common::exists(this->logDir + "(1)"));
@@ -1644,7 +1644,7 @@ TEST_F(LogSystemTest, LogCompressCmdLine)
     EXPECT_TRUE(common::exists(recordPath));
     EXPECT_TRUE(common::exists(defaultCmpPath));
 
-    // Command line triggers ign.cc, which handles creating a unique path if
+    // Command line triggers gz.cc, which handles creating a unique path if
     // file already exists, so as to not overwrite
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 --log-compress "
       + "--record-path " + recordPath + " "
@@ -1675,7 +1675,7 @@ TEST_F(LogSystemTest, LogCompressCmdLine)
     EXPECT_FALSE(common::exists(recordPath));
     EXPECT_TRUE(common::exists(this->AppendExtension(recordPath, "(1).zip")));
 
-    // Command line triggers ign.cc, which handles creating a unique path if
+    // Command line triggers gz.cc, which handles creating a unique path if
     // file already exists, so as to not overwrite
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 --log-compress "
       + "--record-path " + recordPath + " "
@@ -1721,7 +1721,7 @@ TEST_F(LogSystemTest, LogResources)
 #ifndef __APPLE__
   // Log resources from command line
   {
-    // Command line triggers ign.cc, which handles initializing ignLogDirectory
+    // Command line triggers gz.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + "--record --record-resources --record-path " + recordPath + " "
       + kSdfFileOpt + recordSdfPath;
@@ -1739,7 +1739,7 @@ TEST_F(LogSystemTest, LogResources)
   // Recorded models should exist
   EXPECT_GT(entryCount(recordPath), 2);
   EXPECT_TRUE(common::exists(common::joinPaths(recordPath, homeFake,
-      ".ignition", "fuel", "fuel.ignitionrobotics.org", "openrobotics",
+      ".ignition", "fuel", "fuel.gazebosim.org", "openrobotics",
       "models", "x2 config 1")));
 
   // Remove artifacts. Recreate new directory
@@ -1766,7 +1766,7 @@ TEST_F(LogSystemTest, LogResources)
   }
 
   // Console log is not created because ignLogDirectory() is not initialized,
-  // as ign.cc is not executed by command line.
+  // as gz.cc is not executed by command line.
   EXPECT_TRUE(common::exists(statePath));
 
   // Recorded models should exist
@@ -1774,7 +1774,7 @@ TEST_F(LogSystemTest, LogResources)
   EXPECT_GT(entryCount(recordPath), 1);
 #endif
   EXPECT_TRUE(common::exists(common::joinPaths(recordPath, homeFake,
-      ".ignition", "fuel", "fuel.ignitionrobotics.org", "openrobotics",
+      ".ignition", "fuel", "fuel.gazebosim.org", "openrobotics",
       "models", "x2 config 1")));
 
   // Revert environment variable after test is done
@@ -1808,7 +1808,7 @@ TEST_F(LogSystemTest, LogTopics)
 #ifndef __APPLE__
   // Log only the /clock topic from command line
   {
-    // Command line triggers ign.cc, which handles initializing ignLogDirectory
+    // Command line triggers gz.cc, which handles initializing ignLogDirectory
     std::string cmd = kIgnCommand + " -r -v 4 --iterations 5 "
       + "--record-topic /clock "
       + "--record-path " + recordPath + " "
