@@ -17,29 +17,29 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/msgs/empty.pb.h>
-#include <ignition/msgs/vector3d.pb.h>
-#include <ignition/msgs/pose.pb.h>
+#include <gz/msgs/empty.pb.h>
+#include <gz/msgs/vector3d.pb.h>
+#include <gz/msgs/pose.pb.h>
 
 #include <sdf/Root.hh>
 #include <sdf/World.hh>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Util.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/test_config.hh"
+#include "gz/sim/Server.hh"
+#include "gz/sim/SystemLoader.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/test_config.hh"
 
 #include "plugins/MockSystem.hh"
 #include "../helpers/EnvTestFixture.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 using namespace std::chrono_literals;
 
 class TriggeredPublisherTest : public InternalFixture<::testing::Test>
